@@ -1,5 +1,5 @@
 <?php
-//VERSION=0.3
+//VERSION=0.4
 $info = get_token_info();
 
 $user = $info['email'];
@@ -33,9 +33,16 @@ function die_rm($str, $file)
 
 function get_token_info()
 {
-	if (!isset($_POST['token']) || !valid_token($_POST['token']))
+	if (!isset($_POST['token']) && !isset($_GET['token']))
+		die_error('Missing token');
+
+	if (isset($_POST['token']))
+		$token = $_POST['token'];
+	else
+		$token = $_GET['token'];
+
+	if (!valid_token($token))
 		die_error('Invalid token');
-	$token = $_POST['token'];
 
 	$dir = dirname($_SERVER['SCRIPT_FILENAME']);
 	$token_file = $dir.'/tokens/'.$token;
